@@ -47,7 +47,7 @@ def get_info_json_multiple(page=None, page_modifier=None, limit=None, tags=None,
                 raise TypeError("The 'page_modifier' parameter must be a string")
             if page_modifier not in ["a", "b"]:
                 raise ValueError("The 'page_modifier' parameter must be either 'a' (after) or 'b' (before)")
-            url += "&page={}()".format(page_modifier, page)
+            url += "&page={}{}".format(page_modifier, page)
         else:
             url += "&page={}".format(page) 
     elif page != None:
@@ -59,6 +59,7 @@ def get_info_json_multiple(page=None, page_modifier=None, limit=None, tags=None,
         url += "&tags={}".format(tags)
     
     # Get the data
+    print(url)
     headers = {"User-Agent": user_agent}
     
     r = requests.get(url, headers=headers)
@@ -113,12 +114,11 @@ def get_tags_from_json(info_json):
         tags_out.append("source: {}".format(source))
     
     return tags_out
-    
+
 def print_if_true(in_string, do_print):
     if do_print:
         print(in_string)
 def download_image(post_id, output_folder=".", name_pattern=__default_name_pattern__, add_tags=True, messages=True, custom_json=None, user_agent=__default_user_agent__):
-    print_if_true("[{}] Downloading e621 post...".format(post_id), messages)
     # Get information from e621 API
     if custom_json != None:
         image_info = custom_json
@@ -138,6 +138,10 @@ def download_image(post_id, output_folder=".", name_pattern=__default_name_patte
         print_if_true("    ERROR: Image has no download URL.", messages)
         return None
     
+    # Create destination folder if it doesn't already exist
+    #output_folder = os.path.realpath(output_folder)
+    os.makedirs(output_folder, exist_ok=True)
+    
     # Download image
     print_if_true("    Downloading image...", messages)
     image_name = name_pattern.format(m = image_info["file"]["md5"], i = post_id) + "." + image_info["file"]["ext"]
